==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/GridColumnOptionsSimpleSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GridColumnOptionsSimpleSectionBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnOptionsSimpleSectionBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a == null) {
                GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
            }
            if (a.k(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("Caption", "String");
            a.item("ShowCaption", "Boolean");
        }
        static d(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.b(a);
            a.ac("GridColumnOptionsSimpleSectionBase", GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
        }
    }
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnOptionsSimpleSectionBaseDescriptionMetadata, 'GridColumnOptionsSimpleSectionBaseDescriptionMetadata');
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSimpleSectionBaseDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/GridColumnOptionsSimpleSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GridColumnOptionsSimpleSectionBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnOptionsSimpleSectionBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a == null) {
                GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
            }
            if (a.k(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("Caption", "String");
            a.item("ShowCaption", "Boolean");
        }
        static d(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.b(a);
            a.ad("GridColumnOptionsSimpleSectionBase", GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a);
        }
    }
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnOptionsSimpleSectionBaseDescriptionMetadata, 'GridColumnOptionsSimpleSectionBaseDescriptionMetadata');
    GridColumnOptionsSimpleSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSimpleSectionBaseDescriptionMetadata;
})();
